@@ -1,9 +1,9 @@
-copreg<-function(x,y,R,S=R,family=1,exposure=rep(1,length(y)),sd.error=FALSE,joint=TRUE){
+copreg<-function(x,y,R,S=R,family=1,exposure=rep(1,length(y)),sd.error=FALSE,joint=TRUE,zt=TRUE){
 	# fit marginal model
-	mar<-mle_marginal(x,y,R,S,family,exposure=exposure,sd.error=sd.error)
+	mar<-mle_marginal(x,y,R,S,family,exposure=exposure,sd.error=sd.error,zt=zt)
  	# fit joint model
 	if (joint==TRUE){
-		joi<-mle_joint(mar$alpha,mar$beta,mar$theta.ifm,mar$delta,x,y,R,S,family,exposure,sd.error)
+		joi<-mle_joint(mar$alpha,mar$beta,mar$theta.ifm,mar$delta,x,y,R,S,family,exposure,sd.error,zt=zt)
 	}
 	else {
 		joi<-mar
@@ -32,7 +32,7 @@ copreg<-function(x,y,R,S=R,family=1,exposure=rep(1,length(y)),sd.error=FALSE,joi
 	loglik0<-mar$loglik
 	
 	}
-	outlist<-list(alpha0=alpha0,beta0=beta0,delta0=delta0,theta0=theta0,tau0=tau0,theta_IFM=theta_IFM,tau_IFM=tau_IFM,sd.alpha0=sd.alpha0,sd.beta0=sd.beta0,family0=family0,loglik0=loglik0,alpha=alpha,beta=beta,delta=delta,theta=theta,tau=tau,sd.alpha=sd.alpha,sd.beta=sd.beta,family=family,loglik=loglik)
+	outlist<-list(alpha0=alpha0,beta0=beta0,delta0=delta0,theta0=theta0,tau0=tau0,theta_IFM=theta_IFM,tau_IFM=tau_IFM,sd.alpha0=sd.alpha0,sd.beta0=sd.beta0,family0=family0,loglik0=loglik0,alpha=alpha,beta=beta,delta=delta,theta=theta,tau=tau,sd.alpha=sd.alpha,sd.beta=sd.beta,family=family,loglik=loglik,zt=zt)
 	class(outlist)="copreg"	
 return(outlist)
 
